@@ -1,10 +1,14 @@
-( cd usr/share/doc/totem-1.0.4 ; rm -rf build )
-( cd usr/share/doc/totem-1.0.4 ; ln -sf /usr/src/garnome-Ptgz-kit build )
-( cd usr/lib ; rm -rf libtotem-plparser.so.0 )
-( cd usr/lib ; ln -sf libtotem-plparser.so.0.0.0 libtotem-plparser.so.0 )
+( cd usr/lib/nautilus/extensions-1.0 ; rm -rf libtotem-properties-page.so.0 )
+( cd usr/lib/nautilus/extensions-1.0 ; ln -sf libtotem-properties-page.so.0.0.0 libtotem-properties-page.so.0 )
+( cd usr/lib/nautilus/extensions-1.0 ; rm -rf libtotem-properties-page.so )
+( cd usr/lib/nautilus/extensions-1.0 ; ln -sf libtotem-properties-page.so.0.0.0 libtotem-properties-page.so )
 ( cd usr/lib ; rm -rf libtotem-plparser.so )
-( cd usr/lib ; ln -sf libtotem-plparser.so.0.0.0 libtotem-plparser.so )
-#%% begin initialize totem-1.0.4-i386-P1
+( cd usr/lib ; ln -sf libtotem-plparser.so.0.1.0 libtotem-plparser.so )
+( cd usr/lib ; rm -rf libtotem-plparser.so.0 )
+( cd usr/lib ; ln -sf libtotem-plparser.so.0.1.0 libtotem-plparser.so.0 )
+( cd usr/share/doc/totem-1.2.0 ; rm -rf build )
+( cd usr/share/doc/totem-1.2.0 ; ln -sf /usr/src/garnome-Ptgz-kit build )
+#%% begin initialize totem-1.2.0-i386-P1
 if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database /usr/share/applications
 fi
